@@ -1,4 +1,4 @@
-/* Time-stamp: <2003-11-07 00:18:44 jcs>
+/* Time-stamp: <2005-03-02 18:36:05 jcs>
 |
 |  Copyright (C) 2002-2003 Jorg Schuler <jcsjcs at users.sourceforge.net>
 |  Part of the gtkpod project.
@@ -23,7 +23,7 @@
 | 
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: charset.c,v 1.18 2004/01/17 09:37:48 jcsjcs Exp $
+|  $Id: charset.c,v 1.19 2004/12/16 13:52:50 jcsjcs Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -437,10 +437,10 @@ gchar *charset_to_charset (const gchar *from_charset,
 			     &bytes_read,  /* *bytes_read       */
 			     NULL,         /* *bytes_written    */
 			     NULL);        /* GError **error    */
-	    if (bytes_read > br0)  br0 = bytes_read; /* max. nr. of
-							converted Bytes */
-	    if (br == bytes_read)  ++bytes_read; /* don't do an
-						    infinite loop */
+	    /* max. nr. of converted Bytes */
+	    if (bytes_read > br0)  br0 = bytes_read;
+	    /* don't do an infinite loop */
+	    if (bytes_read <= br)  bytes_read = br + 1;
 	}
 	if (ret == NULL)
 	{ /* still no valid string */
@@ -456,8 +456,8 @@ gchar *charset_to_charset (const gchar *from_charset,
 	    }
 	    if (ret == NULL)
 	    { /* Well... what do you think we should return? */
-		/* ret = g_strdup (_("gtkpod: Invalid Conversion")); */
-		ret = g_strdup ("");
+		ret = g_strdup (_("gtkpod: Invalid Conversion"));
+		/* ret = g_strdup ("");*/
 	    }
 	}
 	g_free (strc);
