@@ -1,29 +1,29 @@
-/* Time-stamp: <2003-11-30 13:05:17 jcs>
+/* Time-stamp: <2005-01-03 18:09:49 jcs>
 |
 |  Copyright (C) 2002-2003 Jorg Schuler <jcsjcs at users.sourceforge.net>
 |  Part of the gtkpod project.
-| 
+|
 |  URL: http://gtkpod.sourceforge.net/
-| 
+|
 |  This program is free software; you can redistribute it and/or modify
 |  it under the terms of the GNU General Public License as published by
 |  the Free Software Foundation; either version 2 of the License, or
 |  (at your option) any later version.
-| 
+|
 |  This program is distributed in the hope that it will be useful,
 |  but WITHOUT ANY WARRANTY; without even the implied warranty of
 |  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 |  GNU General Public License for more details.
-| 
+|
 |  You should have received a copy of the GNU General Public License
 |  along with this program; if not, write to the Free Software
 |  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-| 
+|
 |  iTunes and iPod are trademarks of Apple
-| 
+|
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: display.c,v 1.94 2004/01/17 09:37:48 jcsjcs Exp $
+|  $Id: display.c,v 1.103 2004/10/01 16:11:46 jcsjcs Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -40,6 +40,8 @@
 #include "support.h"
 
 
+GtkWidget *gtkpod_window = NULL;
+
 /* used for stopping of display refresh */
 gint stop_add = SORT_TAB_MAX;
 
@@ -69,51 +71,55 @@ gboolean pmtm_move_pathlist (GtkTreeView *treeview,
     /* Convert the list of paths into a list of iters */
     while (*pathp)
     {
-	/* check that we won't move the master playlist (path = "0") */
-	if (!( (tvt == PLAYLIST_TREEVIEW) && (atoi (*pathp) == 0) ))
+	from_iter = g_malloc (sizeof (GtkTreeIter));
+	if ((strlen (*pathp) > 0) &&
+	    gtk_tree_model_get_iter_from_string (model, from_iter, *pathp))
 	{
-	    from_iter = g_malloc (sizeof (GtkTreeIter));
-	    if ((strlen (*pathp) > 0) &&
-		gtk_tree_model_get_iter_from_string (model, from_iter, *pathp))
+	    /* check that we won't move the master playlist */
+	    if (tvt == PLAYLIST_TREEVIEW)
 	    {
-		iterlist = g_list_append (iterlist, from_iter);
+		Playlist *pl;
+		gtk_tree_model_get (model, from_iter,
+				    PM_COLUMN_PLAYLIST, &pl,
+				    -1);
+		if (pl && (pl->type == PL_TYPE_MPL))
+		{
+		    g_free (from_iter);
+		    from_iter = NULL;
+		}
 	    }
+	    if (from_iter)
+		iterlist = g_list_append (iterlist, from_iter);
 	}
 	++pathp;
     }
     g_strfreev (paths);
     /* Move the iters in iterlist before or after @to_iter */
-    switch (pos)
+    for (link = g_list_last (iterlist); link; link = link->prev)
     {
-    case GTK_TREE_VIEW_DROP_INTO_OR_BEFORE:
-    case GTK_TREE_VIEW_DROP_INTO_OR_AFTER:
-    case GTK_TREE_VIEW_DROP_AFTER:
-	for (link = g_list_last (iterlist); link; link = link->prev)
+	from_iter = (GtkTreeIter *)link->data;
+	switch (pos)
 	{
-	    from_iter = (GtkTreeIter *)link->data;
+	case GTK_TREE_VIEW_DROP_INTO_OR_BEFORE:
+	case GTK_TREE_VIEW_DROP_INTO_OR_AFTER:
+	case GTK_TREE_VIEW_DROP_AFTER:
 	    if (tvt == TRACK_TREEVIEW)
 		tm_list_store_move_after (GTK_LIST_STORE (model),
 					  from_iter, &to_iter);
 	    if (tvt == PLAYLIST_TREEVIEW)
-		pm_list_store_move_after (GTK_LIST_STORE (model),
-					  from_iter, &to_iter);
-	}
-	break;
-    case GTK_TREE_VIEW_DROP_BEFORE:
-	for (link = g_list_first (iterlist); link; link = link->next)
-	{
-	    from_iter = (GtkTreeIter *)link->data;
-
+		gtk_tree_store_move_before (GTK_TREE_STORE (model),
+					    from_iter, &to_iter);
+	    break;
+	case GTK_TREE_VIEW_DROP_BEFORE:
 	    if (tvt == TRACK_TREEVIEW)
 		tm_list_store_move_before (GTK_LIST_STORE (model),
 					   from_iter, &to_iter);
 	    if (tvt == PLAYLIST_TREEVIEW)
-		pm_list_store_move_before (GTK_LIST_STORE (model),
-					   from_iter, &to_iter);
+		gtk_tree_store_move_before (GTK_TREE_STORE (model),
+					    from_iter, &to_iter);
+	    break;
 	}
-	break;
     }
-
     /* free iterlist */
     for (link = iterlist; link; link = link->next)
 	g_free (link->data);
@@ -148,7 +154,14 @@ void display_create (GtkWidget *gtkpod)
     tm_sort (prefs_get_tm_sortcol (), prefs_get_tm_sort ());
     /* activate the delete menus correctly */
     display_adjust_delete_menus ();
+    /* activate/deactive the menu item 'check iPod' */
+    display_set_check_ipod_menu ();
+    /* activate status bars */
+    gtkpod_statusbar_init ();
+    gtkpod_tracks_statusbar_init ();
+    gtkpod_space_statusbar_init ();
     /* set the menu item for the info window correctly */
+    /* CAREFUL: must be done after calling ..._space_statusbar_init() */
     display_set_info_window_menu ();
     /* check if info window should be opened */
     if (prefs_get_info_window ())  info_open_window ();
@@ -160,7 +173,7 @@ void display_create (GtkWidget *gtkpod)
    -2: all treeviews
    -1: only playlist
     0...SORT_TAB_MAX-1: sort tab of instance @inst
-    SORT_TAB_MAX: track treeview 
+    SORT_TAB_MAX: track treeview
     SORT_TAB_MAX+1: all sort tabs */
 void display_reset (gint inst)
 {
@@ -211,7 +224,7 @@ void
 display_disable_gtkpod_import_buttons(void)
 {
     GtkWidget *w = NULL;
-    
+
     if(gtkpod_window)
     {
 	if((w = lookup_widget(gtkpod_window, "import_button")))
@@ -308,6 +321,19 @@ void display_set_info_window_menu (void)
     }
 }
 
+/** Takes care about 'Check IPOD Files' Menu Item and makes it unavailable
+ * if gtkpod is offline or DB wasn't imported.
+ */
+void display_set_check_ipod_menu (void)
+{
+    GtkWidget *w = NULL;
+
+    if((w = lookup_widget(gtkpod_window, "check_ipod_files_mi")))
+        gtk_widget_set_sensitive(w, !prefs_get_offline());
+    else
+        g_warning ("check_ipod_files_mi(): Programming error: widget check_ipod_files_mi must be found\n");
+}
+
 /* make the tooltips visible or hide it depending on the value set in
  * the prefs (tooltips_main) */
 void display_show_hide_tooltips (void)
@@ -380,7 +406,7 @@ void display_update_default_sizes (void)
 
 /* Utility function: returns a copy of the tracks currently
    selected. This means:
- 
+
    @inst == -1:
       return list of tracks in selected playlist
 
@@ -433,7 +459,7 @@ GList *display_get_selected_members (gint inst)
 
 /* ------------------------------------------------------------
 
-           Functions for stopping display update 
+           Functions for stopping display update
 
    ------------------------------------------------------------ */
 
@@ -566,7 +592,7 @@ static void block_release_selection (gint inst, gint action,
 		r_user_data2 = user_data2;
 		if (timeout_id == 0)
 		{
-		    timeout_id = 
+		    timeout_id =
 			gtk_idle_add_priority (G_PRIORITY_HIGH_IDLE,
 					       selection_callback_timeout,
 					       NULL);
@@ -665,3 +691,15 @@ gboolean selection_callback_timeout (gpointer data)
     block_release_selection (0, BR_CALL, NULL, NULL, NULL);
     return FALSE;
 }
+
+
+
+/* Put all treeviews into the unsorted state (@enable=FALSE) or back
+   to the sorted state (@enable=TRUE) */
+/* Indicates that we begin adding playlists from iTunesDB.
+   This is a good time to stop sorting display. */
+void display_enable_disable_view_sort (gboolean enable)
+{
+    st_enable_disable_view_sort (0, enable);
+/*    tm_enable_disable_view_sort (enable);*/
+}
