@@ -22,7 +22,7 @@
 | 
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: display_playlists.c,v 1.14 2004/01/17 09:37:48 jcsjcs Exp $
+|  $Id: display_playlists.c,v 1.24 2004/12/18 04:19:50 jcsjcs Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -172,6 +172,7 @@ void pm_add_playlist (Playlist *playlist, gint position)
   }
 }
 
+
 /* Used by pm_remove_playlist() to remove playlist from model by calling
    gtk_tree_model_foreach () */ 
 static gboolean pm_delete_playlist_fe (GtkTreeModel *model,
@@ -265,35 +266,67 @@ void pm_remove_all_playlists (gboolean clear_sort)
 }
 
 
-/* Used by pm_select_playlist() to select the specified playlist by
-   calling gtk_tree_model_foreach () */ 
-static gboolean pm_select_playlist_fe (GtkTreeModel *model,
-				       GtkTreePath *path,
-				       GtkTreeIter *iter,
-				       gpointer data)
-{
-    Playlist *playlist;
-
-    gtk_tree_model_get (model, iter, PM_COLUMN_PLAYLIST, &playlist, -1);
-    if(playlist == data)
-    {
-	GtkTreeSelection *ts = gtk_tree_view_get_selection (playlist_treeview);
-	gtk_tree_selection_select_iter (ts, iter);
-	return TRUE;
-    }
-    return FALSE;
-}
-
 /* Select specified playlist */
 void pm_select_playlist (Playlist *playlist)
 {
-  GtkTreeModel *model = gtk_tree_view_get_model (playlist_treeview);
+    static gboolean pm_select_playlist_fe (GtkTreeModel *model,
+					   GtkTreePath *path,
+					   GtkTreeIter *iter,
+					   gpointer data)
+	{
+	    Playlist *playlist;
 
-  if (model != NULL)
-  {
-      /* find the pl and select it */
-      gtk_tree_model_foreach (model, pm_select_playlist_fe, playlist);
-  }
+	    gtk_tree_model_get (model, iter,
+				PM_COLUMN_PLAYLIST, &playlist, -1);
+	    if(playlist == data)
+	    {
+		GtkTreeSelection *ts = gtk_tree_view_get_selection (
+		    playlist_treeview);
+		gtk_tree_selection_select_iter (ts, iter);
+		return TRUE;
+	    }
+	    return FALSE;
+	}
+    GtkTreeModel *model = gtk_tree_view_get_model (playlist_treeview);
+
+    if (model != NULL)
+    {
+	/* find the pl and select it */
+	gtk_tree_model_foreach (model, pm_select_playlist_fe,
+				playlist);
+    }
+}
+
+
+/* Unselect specified playlist */
+void pm_unselect_playlist (Playlist *playlist)
+{
+    static gboolean pm_unselect_playlist_fe (GtkTreeModel *model,
+					     GtkTreePath *path,
+					     GtkTreeIter *iter,
+					     gpointer data)
+	{
+	    Playlist *playlist;
+
+	    gtk_tree_model_get (model, iter,
+				PM_COLUMN_PLAYLIST, &playlist, -1);
+	    if(playlist == data)
+	    {
+		GtkTreeSelection *ts = gtk_tree_view_get_selection (
+		    playlist_treeview);
+		gtk_tree_selection_unselect_iter (ts, iter);
+		return TRUE;
+	    }
+	    return FALSE;
+	}
+    GtkTreeModel *model = gtk_tree_view_get_model (playlist_treeview);
+
+    if (model != NULL)
+    {
+	/* find the pl and select it */
+	gtk_tree_model_foreach (model, pm_unselect_playlist_fe,
+				playlist);
+    }
 }
 
 
@@ -339,6 +372,7 @@ static void pm_selection_changed_cb (gpointer user_data1, gpointer user_data2)
 	      block_selection (-1);
 	      g_get_current_time (&time);
 	  }
+	  st_enable_disable_view_sort (0, FALSE);
 	  for (gl=new_playlist->members; gl; gl=gl->next)
 	  { /* add all tracks to sort tab 0 */
 	      Track *track = gl->data;
@@ -361,6 +395,7 @@ static void pm_selection_changed_cb (gpointer user_data1, gpointer user_data2)
 #endif
 	      }
 	  }
+	  st_enable_disable_view_sort (0, TRUE);
 	  if (stop_add != -1) st_add_track (NULL, TRUE, TRUE, 0);
 	  if (!prefs_get_block_display ())
 	  {
@@ -387,6 +422,7 @@ static void pm_selection_changed_cb (gpointer user_data1, gpointer user_data2)
 static void pm_selection_changed (GtkTreeSelection *selection,
 				  gpointer user_data)
 {
+    space_data_update ();
     if (!pm_selection_blocked)
 	add_selection_callback (-1, pm_selection_changed_cb,
 				(gpointer)selection, user_data);
@@ -621,24 +657,68 @@ static void pm_cell_data_func (GtkTreeViewColumn *tree_column,
   gint column;
 
   column = (gint)g_object_get_data (G_OBJECT (renderer), "column");
-  gtk_tree_model_get (model, iter, PM_COLUMN_PLAYLIST, &playlist, -1);
+  gtk_tree_model_get (model, iter, column, &playlist, -1);
 
   switch (column)
     {  /* We only have one column, so this code is overkill... */
     case PM_COLUMN_PLAYLIST: 
-	g_object_set (G_OBJECT (renderer),
-		      "text", playlist->name, 
-		      "editable", TRUE,
-		      "foreground", NULL,
-		      NULL);
 	if (playlist->type == PL_TYPE_MPL)
-	{ /* mark MPL in red */
-	    g_object_set (G_OBJECT (renderer), "foreground", "red", NULL);
+	{   /* mark MPL */
+	    g_object_set (G_OBJECT (renderer),
+			  "text", playlist->name, 
+			  "editable", TRUE,
+			  "weight", PANGO_WEIGHT_BOLD,
+			  NULL);
+	}
+	else
+	{
+	    g_object_set (G_OBJECT (renderer),
+			  "text", playlist->name, 
+			  "editable", TRUE,
+			  "weight", PANGO_WEIGHT_NORMAL,
+			  NULL);
 	}
 	break;
     }
 }
 
+
+/* set graphic indicator for smart playlists */
+static void pm_cell_data_func_pix (GtkTreeViewColumn *tree_column,
+				   GtkCellRenderer   *renderer,
+				   GtkTreeModel      *model,
+				   GtkTreeIter       *iter,
+				   gpointer           data)
+{
+  Playlist *playlist;
+  gint column;
+
+  column = (gint)g_object_get_data (G_OBJECT (renderer), "column");
+  gtk_tree_model_get (model, iter, column, &playlist, -1);
+
+  switch (column)
+    {  /* We only have one column, so this code is overkill... */
+    case PM_COLUMN_PLAYLIST: 
+	if (playlist->is_spl)
+	{
+	    g_object_set (G_OBJECT (renderer),
+			  "stock-id", "gtk-properties", NULL);
+	}
+	else if (playlist->type != PL_TYPE_MPL)
+	{
+	    g_object_set (G_OBJECT (renderer),
+			  "stock-id", "gtk-justify-left", NULL);
+	}
+	else
+	{
+	    g_object_set (G_OBJECT (renderer),
+			  "stock-id", NULL, NULL);
+	}
+	break;
+    }
+}
+
+
 /* Adds the columns to our playlist_treeview */
 static void pm_add_columns ()
 {
@@ -646,14 +726,9 @@ static void pm_add_columns ()
   GtkCellRenderer *renderer;
   GtkTreeModel *model = gtk_tree_view_get_model (playlist_treeview);
 
-
   /* playlist column */
-  renderer = gtk_cell_renderer_text_new ();
-  g_signal_connect (G_OBJECT (renderer), "edited",
-		    G_CALLBACK (pm_cell_edited), model);
-  g_object_set_data (G_OBJECT (renderer), "column", (gint *)PM_COLUMN_PLAYLIST);
-  column = gtk_tree_view_column_new_with_attributes (_("Playlists"), renderer, NULL);
-  gtk_tree_view_column_set_cell_data_func (column, renderer, pm_cell_data_func, NULL, NULL);
+  column = gtk_tree_view_column_new ();
+  gtk_tree_view_column_set_title (column, _("Playlists"));
   gtk_tree_view_column_set_sort_column_id (column, PM_COLUMN_PLAYLIST);
   gtk_tree_view_column_set_resizable (column, TRUE);
   gtk_tree_view_column_set_sort_order (column, GTK_SORT_ASCENDING);
@@ -665,6 +740,21 @@ static void pm_add_columns ()
 		    G_CALLBACK (pm_track_column_button_clicked),
 				(gpointer)PM_COLUMN_PLAYLIST);
   gtk_tree_view_append_column (playlist_treeview, column);
+
+  /* cell for playlist name */
+  renderer = gtk_cell_renderer_text_new ();
+  g_signal_connect (G_OBJECT (renderer), "edited",
+		    G_CALLBACK (pm_cell_edited), model);
+  g_object_set_data (G_OBJECT (renderer), "column", (gint *)PM_COLUMN_PLAYLIST);
+  gtk_tree_view_column_pack_end (column, renderer, FALSE);
+  gtk_tree_view_column_set_cell_data_func (column, renderer, pm_cell_data_func, NULL, NULL);
+
+
+  /* cell for graphic indicator */
+  renderer = gtk_cell_renderer_pixbuf_new ();
+  g_object_set_data (G_OBJECT (renderer), "column", (gint *)PM_COLUMN_PLAYLIST);
+  gtk_tree_view_column_pack_start (column, renderer, FALSE); 
+  gtk_tree_view_column_set_cell_data_func (column, renderer, pm_cell_data_func_pix, NULL, NULL);
 }
 
 
@@ -789,6 +879,9 @@ pm_get_selected_playlist(void)
 				PM_COLUMN_PLAYLIST, &result, -1);
 	}
     }
+    /* playlist was just changed -- wait until current_playlist is
+       updated. */
+    if (result != current_playlist)  result=NULL;
     return result;
 }
 
@@ -912,14 +1005,14 @@ on_pm_dnd_get_file_foreach(GtkTreeModel *tm, GtkTreePath *tp,
     gtk_tree_model_get(tm, iter, PM_COLUMN_PLAYLIST, &pl, -1); 
     if (pl && filelist)
     {
-	Track *s;
+	Track *track;
 	gchar *name;
 	GList *l;
 
 	for (l=pl->members; l; l=l->next)
 	{
-	    s = (Track *)l->data;
-	    name = get_track_name_on_disk_verified (s);
+	    track = (Track *)l->data;
+	    name = get_track_name_on_disk_verified (track);
 	    if (name)
 	    {
 		g_string_append_printf (filelist, "file:%s\n", name);
