@@ -1,29 +1,29 @@
-/* Time-stamp: <2004-01-12 17:27:28 jcs>
+/* Time-stamp: <2004-12-18 13:12:56 jcs>
 |
 |  Copyright (C) 2002-2003 Jorg Schuler <jcsjcs at users.sourceforge.net>
 |  Part of the gtkpod project.
-| 
+|
 |  URL: http://gtkpod.sourceforge.net/
-| 
+|
 |  This program is free software; you can redistribute it and/or modify
 |  it under the terms of the GNU General Public License as published by
 |  the Free Software Foundation; either version 2 of the License, or
 |  (at your option) any later version.
-| 
+|
 |  This program is distributed in the hope that it will be useful,
 |  but WITHOUT ANY WARRANTY; without even the implied warranty of
 |  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 |  GNU General Public License for more details.
-| 
+|
 |  You should have received a copy of the GNU General Public License
 |  along with this program; if not, write to the Free Software
 |  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-| 
+|
 |  iTunes and iPod are trademarks of Apple
-| 
+|
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: display_sorttabs.c,v 1.26 2004/01/17 09:37:48 jcsjcs Exp $
+|  $Id: display_sorttabs.c,v 1.41 2004/12/18 04:19:51 jcsjcs Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -91,7 +91,7 @@ static void sp_remove_all_members (guint32 inst)
 
 /* Return a pointer to ti_created, ti_modified or ti_played. Returns
    NULL if either inst or item are out of range */
-static TimeInfo *st_get_timeinfo_ptr (guint32 inst, T_item item)
+static TimeInfo *sp_get_timeinfo_ptr (guint32 inst, T_item item)
 {
     if (inst >= SORT_TAB_MAX)
     {
@@ -102,6 +102,8 @@ static TimeInfo *st_get_timeinfo_ptr (guint32 inst, T_item item)
 	SortTab *st = sorttab[inst];
 	switch (item)
 	{
+	case T_TIME_CREATED:
+	    return &st->ti_created;
 	case T_TIME_PLAYED:
 	    return &st->ti_played;
 	case T_TIME_MODIFIED:
@@ -122,7 +124,7 @@ static TimeInfo *st_get_timeinfo_ptr (guint32 inst, T_item item)
    message again, if necessary */
 /* Return value: pointer to the corresponding TimeInfo struct (for
    convenience) or NULL if error occured */
-TimeInfo *st_update_date_interval_from_string (guint32 inst,
+TimeInfo *sp_update_date_interval_from_string (guint32 inst,
 					       T_item item,
 					       gboolean force_update)
 {
@@ -132,7 +134,7 @@ TimeInfo *st_update_date_interval_from_string (guint32 inst,
     if (inst >= SORT_TAB_MAX) return NULL;
 
     st = sorttab[inst];
-    ti = st_get_timeinfo_ptr (inst, item);
+    ti = sp_get_timeinfo_ptr (inst, item);
 
     if (ti)
     {
@@ -147,7 +149,7 @@ TimeInfo *st_update_date_interval_from_string (guint32 inst,
 	}
     }
     return ti;
-}	
+}
 
 
 /* check if @track's timestamp is within the interval given for @item.
@@ -158,12 +160,12 @@ TimeInfo *st_update_date_interval_from_string (guint32 inst,
  * IS_INSIDE:  track's timestamp is inside the specified interval
  * IS_OUTSIDE: track's timestamp is outside the specified interval
  */
-static IntervalState st_check_time (guint32 inst, T_item item, Track *track)
+static IntervalState sp_check_time (guint32 inst, T_item item, Track *track)
 {
     TimeInfo *ti;
     IntervalState result = IS_ERROR;
 
-    ti = st_update_date_interval_from_string (inst, T_TIME_PLAYED, FALSE);
+    ti = sp_update_date_interval_from_string (inst, item, FALSE);
     if (ti && ti->valid)
     {
 	guint32 stamp = track_get_timestamp (track, item);
@@ -181,6 +183,9 @@ static IntervalState st_check_time (guint32 inst, T_item item, Track *track)
 	case T_TIME_MODIFIED:
 	    gtkpod_statusbar_message (_("'Modified' condition ignored because of error."));
 	    break;
+	case T_TIME_CREATED:
+	    gtkpod_statusbar_message (_("'Created' condition ignored because of error."));
+	    break;
 	default:
 	    break;
 	}
@@ -236,7 +241,7 @@ static gboolean sp_check_track (Track *track, guint32 inst)
     /* time played */
     if (prefs_get_sp_cond (inst, T_TIME_PLAYED))
     {
-	IntervalState result = st_check_time (inst, T_TIME_PLAYED, track);
+	IntervalState result = sp_check_time (inst, T_TIME_PLAYED, track);
 	if (sp_or && (result == IS_INSIDE))      return TRUE;
 	if ((!sp_or) && (result == IS_OUTSIDE))  return FALSE;
 	if (result != IS_ERROR)                  checked = TRUE;
@@ -244,11 +249,20 @@ static gboolean sp_check_track (Track *track, guint32 inst)
     /* time modified */
     if (prefs_get_sp_cond (inst, T_TIME_MODIFIED))
     {
-	IntervalState result = st_check_time (inst, T_TIME_MODIFIED, track);
+	IntervalState result = sp_check_time (inst, T_TIME_MODIFIED, track);
 	if (sp_or && (result == IS_INSIDE))      return TRUE;
 	if ((!sp_or) && (result == IS_OUTSIDE))  return FALSE;
 	if (result != IS_ERROR)                  checked = TRUE;
     }
+    /* time created */
+    if (prefs_get_sp_cond (inst, T_TIME_CREATED))
+    {
+	IntervalState result = sp_check_time (inst, T_TIME_CREATED, track);
+	if (sp_or && (result == IS_INSIDE))      return TRUE;
+	if ((!sp_or) && (result == IS_OUTSIDE))  return FALSE;
+	if (result != IS_ERROR)                  checked = TRUE;
+    }
+
     if (checked) return result;
     else         return FALSE;
 }
@@ -291,7 +305,7 @@ static void st_add_track_special (Track *track, gboolean final,
     {
 	if (st->is_go || prefs_get_sp_autodisplay (inst))
 	    st_add_track (NULL, final, display, inst+1);
-	
+
     }
 }
 
@@ -309,6 +323,8 @@ static void sp_go_cb (gpointer user_data1, gpointer user_data2)
 	    time.tv_sec % 3600, time.tv_usec);
 #endif
 
+    space_data_update ();
+
     /* Sanity */
     if (st == NULL) return;
 
@@ -335,6 +351,7 @@ static void sp_go_cb (gpointer user_data1, gpointer user_data2)
 	    block_selection (inst);
 	    g_get_current_time (&time);
 	}
+	st_enable_disable_view_sort (inst+1, FALSE);
 	for (gl=st->sp_members; gl; gl=gl->next)
 	{ /* add all member tracks to next instance */
 	    Track *track = (Track *)gl->data;
@@ -361,6 +378,7 @@ static void sp_go_cb (gpointer user_data1, gpointer user_data2)
 #endif
 	    }
 	}
+	st_enable_disable_view_sort (inst+1, TRUE);
 	if (stop_add > (gint)inst)
 	    st_add_track (NULL, TRUE, st->final, inst+1);
 	if (!prefs_get_block_display ())
@@ -390,10 +408,12 @@ static void sp_store_sp_entries (gint inst)
     /* Sanity */
     if (!st || (st->current_category != ST_CAT_SPECIAL)) return;
 
-    prefs_set_sp_entry (inst, T_TIME_MODIFIED,
-			gtk_entry_get_text (GTK_ENTRY(st->ti_modified.entry)));
     prefs_set_sp_entry (inst, T_TIME_PLAYED,
 			gtk_entry_get_text (GTK_ENTRY(st->ti_played.entry)));
+    prefs_set_sp_entry (inst, T_TIME_MODIFIED,
+			gtk_entry_get_text (GTK_ENTRY(st->ti_modified.entry)));
+    prefs_set_sp_entry (inst, T_TIME_CREATED,
+			gtk_entry_get_text (GTK_ENTRY(st->ti_created.entry)));
 }
 
 /* display the members satisfying the conditions specified in the
@@ -427,7 +447,7 @@ void sp_go (guint32 inst)
     add_selection_callback (inst, sp_go_cb,
 			    (gpointer)inst, NULL);
 }
-    
+
 
 /* called by st_remove_track() */
 static void st_remove_track_special (Track *track, guint32 inst)
@@ -504,7 +524,7 @@ static void st_track_changed_special (Track *track,
 		    st->sp_selected = g_list_append (st->sp_selected, track);
 		    st_add_track (track, TRUE, TRUE, inst+1);
 		}
-	    }		
+	    }
 	}
     }
 }
@@ -538,7 +558,6 @@ void sp_conditions_changed (guint32 inst)
 /*                                                                  */
 /* ---------------------------------------------------------------- */
 
-
 /* return a pointer to the list of members selected in the sort tab
    @inst. For a normal sort tab this is
    sorttab[inst]->current_entry->members, for a special sort tab this
@@ -624,6 +643,8 @@ TabEntry *st_get_selected_entry (gint inst)
 				ST_COLUMN_ENTRY, &result, -1);
 	}
     }
+    /* wait until current_entry was updated */
+    if (result != sorttab[inst]->current_entry) result=NULL;
     return result;
 }
 
@@ -653,7 +674,7 @@ static void st_add_entry (TabEntry *entry, guint32 inst)
 }
 
 /* Used by st_remove_entry_from_model() to remove entry from model by calling
-   gtk_tree_model_foreach () */ 
+   gtk_tree_model_foreach () */
 static gboolean st_delete_entry_from_model (GtkTreeModel *model,
 					    GtkTreePath *path,
 					    GtkTreeIter *iter,
@@ -693,7 +714,7 @@ static void st_remove_entry_from_model (TabEntry *entry, guint32 inst)
 	/* remove entry from hash */
 	if (st->entry_hash)
 	{
-	    TabEntry *hashed_entry = 
+	    TabEntry *hashed_entry =
 		(TabEntry *)g_hash_table_lookup (st->entry_hash, entry->name);
 	    if (hashed_entry == entry)
 		g_hash_table_remove (st->entry_hash, entry->name);
@@ -904,7 +925,7 @@ static gboolean st_recategorize_track (Track *track, guint32 inst)
   if (newentry != oldentry)
     { /* track category changed */
       /* add track to entry members list */
-      newentry->members = g_list_append (newentry->members, track); 
+      newentry->members = g_list_append (newentry->members, track);
       /* remove track from old entry members list */
       oldentry->members = g_list_remove (oldentry->members, track);
       /*  printf("%d: recat_return_TRUE\n", inst);*/
@@ -1027,10 +1048,12 @@ void st_track_changed (Track *track, gboolean removed, guint32 inst)
 /* Reorders the tracks stored in the sort tabs according to the order
  * in the selected playlist. This has to be done e.g. if we change the
  * order in the track view.
- * 
+ *
  * Right now I simply delete all members of all tab entries, then add
- * the tracks again without having them added to the track view. For my
- * 2459 tracks that takes approx. 1.3 seconds (850 MHz AMD Duron) */
+ * the tracks again without having them added to the track view. This
+ * is very fast because neither the sort tab display nor the track
+ * view display is affected in any way. For my 2459 tracks that takes
+ * approx. 1.3 seconds (850 MHz AMD Duron) */
 void st_adopt_order_in_playlist (void)
 {
     gint inst;
@@ -1167,7 +1190,7 @@ static void st_add_track_normal (Track *track, gboolean final,
 	    return;
 	}
 	do {
-	    gtk_tree_model_get (st->model, &iter, 
+	    gtk_tree_model_get (st->model, &iter,
 				ST_COLUMN_ENTRY, &iter_entry,
 				-1);
 	    if (iter_entry == select_entry)
@@ -1296,7 +1319,7 @@ void st_init (ST_CAT_item new_category, guint32 inst)
 {
   if (inst == prefs_get_sort_tab_num ())
   {
-      tm_remove_all_tracks (TRUE);
+      tm_remove_all_tracks ();
       gtkpod_tracks_statusbar_update ();
       return;
   }
@@ -1403,6 +1426,7 @@ static void st_page_selected_cb (gpointer user_data1, gpointer user_data2)
 	  g_get_current_time (&time);
       }
       /* add all tracks previously present to sort tab */
+      st_enable_disable_view_sort (inst, FALSE);
       for (gl=copy; gl; gl=gl->next)
       {
 	  Track *track = gl->data;
@@ -1425,6 +1449,7 @@ static void st_page_selected_cb (gpointer user_data1, gpointer user_data2)
 #endif
 	  }
       }
+      st_enable_disable_view_sort (inst, TRUE);
       if (stop_add >= (gint)inst)
       {
 	  gboolean final = TRUE;  /* playlist is always complete */
@@ -1564,7 +1589,7 @@ static void st_selection_changed_cb (gpointer user_data1, gpointer user_data2)
   }
   else
   {   /* handle new selection */
-      gtk_tree_model_get (model, &iter, 
+      gtk_tree_model_get (model, &iter,
 			  ST_COLUMN_ENTRY, &new_entry,
 			  -1);
       /* printf("selected instance %d, entry %x (was: %x)\n", inst,
@@ -1593,6 +1618,7 @@ static void st_selection_changed_cb (gpointer user_data1, gpointer user_data2)
 	      block_selection (inst);
 	      g_get_current_time (&time);
 	  }
+	  st_enable_disable_view_sort (inst+1, FALSE);
 	  for (gl=new_entry->members; gl; gl=gl->next)
 	  { /* add all member tracks to next instance */
 	      Track *track = gl->data;
@@ -1615,6 +1641,7 @@ static void st_selection_changed_cb (gpointer user_data1, gpointer user_data2)
 #endif
 	      }
 	  }
+	  st_enable_disable_view_sort (inst+1, TRUE);
 	  if (stop_add > (gint)inst)
 	      st_add_track (NULL, TRUE, st->final, inst+1);
 	  if (!prefs_get_block_display ())
@@ -1644,6 +1671,7 @@ static void st_selection_changed (GtkTreeSelection *selection,
 #if DEBUG_CB_INIT
     printf("st_s_c enter (inst: %d)\n", (gint)user_data);
 #endif
+    space_data_update ();
     add_selection_callback ((gint)user_data, st_selection_changed_cb,
 			    (gpointer)selection, user_data);
 #if DEBUG_CB_INIT
@@ -1703,7 +1731,7 @@ st_cell_edited (GtkCellRendererText *renderer,
 	      g_free (entry->name);
 	      entry->name = g_strdup (new_text);
 	  }
-	  
+
 	  /* re-insert into hash table if the same name doesn't
 	     already exist */
 	  if (g_hash_table_lookup (st->entry_hash, entry->name) == NULL)
@@ -1779,18 +1807,29 @@ static void st_cell_data_func (GtkTreeViewColumn *tree_column,
 {
   TabEntry *entry;
   gint column;
-  gboolean editable;
 
   column = (gint)g_object_get_data (G_OBJECT (renderer), "column");
   gtk_tree_model_get (model, iter, ST_COLUMN_ENTRY, &entry, -1);
 
   switch (column)
     {  /* We only have one column, so this code is overkill... */
-    case ST_COLUMN_ENTRY: 
-      if (entry->master) editable = FALSE;
-      else               editable = TRUE;
-      g_object_set (G_OBJECT (renderer), "text", entry->name, 
-		    "editable", editable, NULL);
+    case ST_COLUMN_ENTRY:
+      if (entry->master)
+      {   /* mark the "All" entry */
+	  g_object_set (G_OBJECT (renderer),
+			"text", entry->name,
+			"editable", FALSE,
+			"weight", PANGO_WEIGHT_BOLD,
+			NULL);
+      }
+      else
+      {
+	  g_object_set (G_OBJECT (renderer),
+			"text", entry->name,
+			"editable", TRUE,
+			"weight", PANGO_WEIGHT_NORMAL,
+			NULL);
+      }
       break;
     }
 }
@@ -1805,6 +1844,10 @@ gint st_data_compare_func (GtkTreeModel *model,
   TabEntry *entry2;
   GtkSortType order;
   gint corr, colid;
+  gint inst;
+  SortTab *st;
+
+  inst = (guint32)user_data;
 
   gtk_tree_model_get (model, a, ST_COLUMN_ENTRY, &entry1, -1);
   gtk_tree_model_get (model, b, ST_COLUMN_ENTRY, &entry2, -1);
@@ -1819,7 +1862,13 @@ gint st_data_compare_func (GtkTreeModel *model,
   if (entry2->master) return (corr);
 
   /* compare the two entries */
-  return compare_string (entry1->name, entry2->name);
+  st = sorttab[inst];
+  switch ( st->current_category ) {
+    case ST_CAT_ARTIST:
+	return compare_string_fuzzy (entry1->name, entry2->name);
+    default:
+	return compare_string (entry1->name, entry2->name);
+  }
 }
 
 /* Stop editing. If @cancel is TRUE, the edited value will be
@@ -1837,7 +1886,7 @@ void st_stop_editing (gint inst, gboolean cancel)
 				      NULL, &col);
 	    if (col)
 	    {
-		if (!cancel && col->editable_widget)  
+		if (!cancel && col->editable_widget)
 		    gtk_cell_editable_editing_done (col->editable_widget);
 		if (col->editable_widget)
 		    gtk_cell_editable_remove_widget (col->editable_widget);
@@ -1847,6 +1896,101 @@ void st_stop_editing (gint inst, gboolean cancel)
 }
 
 
+/* Compare function to avoid sorting */
+static gint st_nosort_comp (GtkTreeModel *model,
+			    GtkTreeIter *a,
+			    GtkTreeIter *b,
+			    gpointer user_data)
+{
+    return 0;
+}
+
+
+
+/* Disable sorting of the view during lengthy updates. */
+/* @enable: TRUE: enable, FALSE: disable */
+void st_enable_disable_view_sort (gint inst, gboolean enable)
+{
+    static gint disable_count[SORT_TAB_MAX];
+
+    if (inst >= prefs_get_sort_tab_num ())
+    {
+	tm_enable_disable_view_sort (enable);
+	return;
+    }
+
+    if (enable)
+    {
+	disable_count[inst]--;
+	if (disable_count[inst] < 0)
+	    fprintf (stderr, "Programming error: disable_count < 0\n");
+	if (disable_count[inst] == 0)
+	{
+	    /* Re-enable sorting */
+	    if ((prefs_get_st_sort () != SORT_NONE) &&
+		prefs_get_disable_sorting ())
+	    {
+		SortTab *st = sorttab[inst];
+		if (st && 
+		    (st->current_category != ST_CAT_SPECIAL) &&
+		    st->model)
+		{
+		    if (BROKEN_GTK_TREE_SORT)
+		    {
+			gtk_tree_sortable_set_sort_func (
+			    GTK_TREE_SORTABLE (st->model),
+			    ST_COLUMN_ENTRY,
+			    st_data_compare_func, (gpointer)inst, NULL);
+		    }
+		    else
+		    {
+			gtk_tree_sortable_set_sort_column_id (
+			    GTK_TREE_SORTABLE (st->model),
+			    ST_COLUMN_ENTRY,
+			    prefs_get_st_sort ());
+		    }
+		}
+	    }
+	    st_enable_disable_view_sort (inst+1, enable);
+	}
+    }
+    else
+    {
+	if (disable_count[inst] == 0)
+	{
+	    /* Disable sorting */
+	    if ((prefs_get_st_sort () != SORT_NONE) &&
+		prefs_get_disable_sorting ())
+	    {
+		SortTab *st = sorttab[inst];
+		if (st && 
+		    (st->current_category != ST_CAT_SPECIAL) &&
+		    st->model)
+		{
+		    if (BROKEN_GTK_TREE_SORT)
+		    {
+			gtk_tree_sortable_set_sort_func (
+			    GTK_TREE_SORTABLE (st->model),
+			    ST_COLUMN_ENTRY,
+			    st_nosort_comp, NULL, NULL);
+		    }
+		    else
+		    {
+			gtk_tree_sortable_set_sort_column_id (
+			    GTK_TREE_SORTABLE (st->model),
+			    GTK_TREE_SORTABLE_UNSORTED_SORT_COLUMN_ID,
+			    prefs_get_st_sort ());
+		    }
+		}
+	    }
+	    st_enable_disable_view_sort (inst+1, enable);
+	}
+	disable_count[inst]++;
+    }
+}
+
+
+
 void st_select_current_position (gint inst, gint x, gint y)
 {
     if (inst < prefs_get_sort_tab_num ())
@@ -2011,7 +2155,7 @@ st_button_press_event(GtkWidget *w, GdkEventButton *e, gpointer data)
 	    default:
 		break;
 	}
-	
+
     }
     return(FALSE);
 }
@@ -2066,7 +2210,7 @@ static void st_create_listview (gint inst)
 	  gtk_tree_view_column_set_sort_order (column, GTK_SORT_ASCENDING);
 	  gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (liststore),
 					   ST_COLUMN_ENTRY,
-					   st_data_compare_func, column, NULL);
+					   st_data_compare_func, (gpointer)inst, NULL);
 	  gtk_tree_view_append_column (treeview, column);
 	  gtk_tree_view_set_headers_visible (treeview, FALSE);
 	  gtk_drag_source_set (GTK_WIDGET (treeview), GDK_BUTTON1_MASK,
@@ -2108,7 +2252,7 @@ static void st_create_special (gint inst, GtkWidget *window)
       {
 	  w = lookup_widget (special, "sp_and_button");
 	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w), TRUE);
-      }	  
+      }
 
       /* RATING */
       w = lookup_widget (special, "sp_rating_button");
@@ -2150,7 +2294,7 @@ static void st_create_special (gint inst, GtkWidget *window)
 			(gpointer)inst);
       gtk_spin_button_set_value (GTK_SPIN_BUTTON (w),
 				 prefs_get_sp_playcount_high (inst));
-      
+
       /* PLAYED */
       w = lookup_widget (special, "sp_played_button");
       st->ti_played.active = w;
@@ -2193,6 +2337,27 @@ static void st_create_special (gint inst, GtkWidget *window)
 			G_CALLBACK (on_sp_cal_button_clicked),
 			(gpointer)((T_TIME_MODIFIED<<SP_SHIFT) + inst));
 
+      /* CREATED */
+      w = lookup_widget (special, "sp_created_button");
+      st->ti_created.active = w;
+      g_signal_connect ((gpointer)w,
+			"toggled", G_CALLBACK (on_sp_cond_button_toggled),
+			(gpointer)((T_TIME_CREATED<<SP_SHIFT) + inst));
+      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(w),
+				   prefs_get_sp_cond (inst, T_TIME_CREATED));
+      w = lookup_widget (special, "sp_created_entry");
+      st->ti_created.entry = w;
+      gtk_entry_set_text (GTK_ENTRY (w),
+			  prefs_get_sp_entry (inst, T_TIME_CREATED));
+      g_signal_connect ((gpointer)w,
+			"activate", G_CALLBACK (on_sp_entry_activate),
+			(gpointer)((T_TIME_CREATED<<SP_SHIFT) + inst));
+      g_signal_connect ((gpointer)lookup_widget (special,
+						 "sp_created_cal_button"),
+			"clicked",
+			G_CALLBACK (on_sp_cal_button_clicked),
+			(gpointer)((T_TIME_CREATED<<SP_SHIFT) + inst));
+
 
       g_signal_connect ((gpointer)lookup_widget (special, "sp_go"),
 			"clicked", G_CALLBACK (on_sp_go_clicked),
@@ -2496,8 +2661,8 @@ void st_show_hide_tooltips (void)
 /*
  * utility function for appending ipod track ids for st treeview callback
  */
-void 
-on_st_listing_drag_foreach(GtkTreeModel *tm, GtkTreePath *tp, 
+void
+on_st_listing_drag_foreach(GtkTreeModel *tm, GtkTreePath *tp,
 			   GtkTreeIter *i, gpointer data)
 {
     TabEntry *entry;
@@ -2532,12 +2697,14 @@ on_st_listing_drag_foreach(GtkTreeModel *tm, GtkTreePath *tp,
 const gchar *cat_strings[] = {
     N_("Last Played"),
     N_("Last Modified"),
+    N_("Created"),
     NULL };
 
 /* enum to access cat_strings */
 enum {
     CAT_STRING_PLAYED = 0,
-    CAT_STRING_MODIFIED = 1 };
+    CAT_STRING_MODIFIED = 1,
+    CAT_STRING_CREATED = 2 };
 
 /* typedef to specify lower or upper margin */
 typedef enum {
@@ -2718,6 +2885,9 @@ static T_item cal_get_category (GtkWidget *cal)
     case CAT_STRING_MODIFIED:
 	item = T_TIME_MODIFIED;
 	break;
+    case CAT_STRING_CREATED:
+	item = T_TIME_CREATED;
+	break;
     default:
 	fprintf (stderr, "Programming error: cal_get_category () -- item not found.\n");
 	/* set to something reasonable at least */
@@ -2725,7 +2895,7 @@ static T_item cal_get_category (GtkWidget *cal)
     }
     return item;
 }
-	
+
 
 /* Returns a string "DD/MM/YYYY HH:MM". Data is taken from
  * @tm. Returns NULL if tm==NULL. You must g_free() the returned
@@ -2757,10 +2927,10 @@ static void cal_apply_data (GtkWidget *cal)
     /* Get selected instance */
     inst = gtk_spin_button_get_value_as_int (
 	GTK_SPIN_BUTTON (lookup_widget (cal, "sorttab_num_spin"))) - 1;
-    /* Get selected category (played or modified) */
+    /* Get selected category (played, modified or created) */
     item = cal_get_category (cal);
     /* Get pointer to corresponding TimeInfo struct */
-    ti = st_get_timeinfo_ptr (inst, item);
+    ti = sp_get_timeinfo_ptr (inst, item);
 
     if (ti)
     {
@@ -2880,13 +3050,13 @@ static void cal_ok (GtkButton *button, gpointer user_data)
 }
 
 /* Open a calendar window. Preset the values for instance @inst,
-   category @item (time played or time modified) */
+   category @item (time played, time modified or time created) */
 void cal_open_calendar (gint inst, T_item item)
 {
     SortTab *st;
     GtkWidget *w;
     GtkWidget *cal;
-    gchar *str;
+    gchar *str = NULL;
     static GList *catlist = NULL;
     gint defx, defy;
     TimeInfo *ti;
@@ -2918,17 +3088,28 @@ void cal_open_calendar (gint inst, T_item item)
 	while (*bp)   catlist = g_list_append (catlist, gettext (*bp++));
     }
     w = lookup_widget (cal, "cat_combo");
-    gtk_combo_set_popdown_strings (GTK_COMBO (w), catlist); 
-    /* set standard entry */
-    if (item == T_TIME_PLAYED)
-	    str = gettext (cat_strings[CAT_STRING_PLAYED]);
-    else    str = gettext (cat_strings[CAT_STRING_MODIFIED]);
+    gtk_combo_set_popdown_strings (GTK_COMBO (w), catlist);
+    switch (item)
+    {
+    case T_TIME_PLAYED:
+	str = gettext (cat_strings[CAT_STRING_PLAYED]);
+	break;
+    case T_TIME_MODIFIED:
+	str = gettext (cat_strings[CAT_STRING_MODIFIED]);
+	break;
+    case T_TIME_CREATED:
+	str = gettext (cat_strings[CAT_STRING_CREATED]);
+	break;
+    default:
+	fprintf (stderr, "Programming error: cal_open_calendar() -- item not found\n");
+	break;
+    }
     gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (w)->entry), str);
 
     /* Make sure we use the current contents of the entry */
     sp_store_sp_entries (inst);
     /* set calendar */
-    ti = st_update_date_interval_from_string (inst, item, TRUE);
+    ti = sp_update_date_interval_from_string (inst, item, TRUE);
     /* set the calendar if we have a valid TimeInfo */
     if (ti)
     {
@@ -2950,7 +3131,7 @@ void cal_open_calendar (gint inst, T_item item)
 			  "toggled",
 			  G_CALLBACK (cal_time_toggled),
 			  cal);
-	
+
 	cal_set_time (cal, LOWER_MARGIN, ti->lower);
 
 	/* Upper Margin */
