@@ -36,6 +36,7 @@
 #include "display.h"
 #include "file.h"
 #include "itunesdb.h"
+#include "itunessd.h"
 #include "md5.h"
 #include "misc.h"
 #include "prefs.h"
@@ -1013,7 +1014,7 @@ static gboolean flush_tracks (void)
 /* used to handle export of database */
 void handle_export (void)
 {
-  gchar *cft=NULL, *cfe=NULL, *cfgdir;
+  gchar *cft=NULL, *cfe=NULL, *cfs=NULL, *cfgdir;
   gboolean success = TRUE;
   gchar *buf;
 
@@ -1022,6 +1023,7 @@ void handle_export (void)
   {
       cft = g_build_filename (cfgdir, "iTunesDB", NULL);
       cfe = g_build_filename (cfgdir, "iTunesDB.ext", NULL);
+      cfs = g_build_filename (cfgdir, "iTunesSD", NULL);
   }
 
   if (!file_itunesdb_read())
@@ -1060,6 +1062,7 @@ void handle_export (void)
 	{
 	    g_free (cft);
 	    g_free (cfe);
+	    g_free (cfs);
 	    return;
 	}
       }
@@ -1098,12 +1101,14 @@ void handle_export (void)
       success = itunesdb_write_to_file (cft);
       if (success)
 	  success = write_extended_info (cfe, cft);
+      if (success)
+	  success = itunessd_write_to_file(cfs);
   }
 
   /* now copy to iPod */
   if(success && !prefs_get_offline ())
   {
-      gchar *ipt = NULL, *ipe = NULL;
+      gchar *ipt = NULL, *ipe = NULL, *ips = NULL;
       gchar *ipod_path_as_filename = 
 	  charset_from_utf8 (prefs_get_ipod_mount());
       const gchar *itunes_components[] = {"iPod_Control", "iTunes", NULL};
@@ -1111,6 +1116,7 @@ void handle_export (void)
 					    itunes_components);
       ipt = g_build_filename (itunes_filename, "iTunesDB", NULL);
       ipe = g_build_filename (itunes_filename, "iTunesDB.ext", NULL);
+      ips = g_build_filename (itunes_filename, "iTunesSD", NULL);
 
       /* copy iTunesDB to iPod */
       while (widgets_blocked && gtk_events_pending ())
@@ -1139,6 +1145,14 @@ void handle_export (void)
 	      g_free (buf);
 	  }
       }
+      if (success)
+      {
+	  success = itunesdb_cp (cfs, ips);
+	  if(!success)
+	  {
+	      gtkpod_statusbar_message (_("Error writing iTunesSD to iPod"));
+	  }
+      }
       if (prefs_get_concal_autosync ())
       {
 	  const gchar *str;
@@ -1152,6 +1166,7 @@ void handle_export (void)
       }
       g_free (ipt);
       g_free (ipe);
+      g_free (ips);
       /* move old playcount file etc out of the way */
       if (success)
 	  itunesdb_rename_files (ipod_path_as_filename);
@@ -1170,6 +1185,7 @@ void handle_export (void)
   g_free (cfgdir);
   g_free (cft);
   g_free (cfe);
+  g_free (cfs);
 
   release_widgets (); /* Allow input again */
 }
