@@ -1,4 +1,4 @@
-/* Time-stamp: <2005-03-10 23:17:49 jcs>
+/* Time-stamp: <2005-03-15 10:11:21 jcs>
 |
 |  Copyright (C) 2002-2003 Jorg Schuler <jcsjcs at users.sourceforge.net>
 |  Part of the gtkpod project.
@@ -1756,7 +1756,7 @@ static void mk_mhbd (FILE *file)
   put32lint (file, 104); /* header size */
   put32lint (file, -1);  /* size of whole mhdb -- fill in later */
   put32lint (file, 1);   /* ? */
-  put32lint (file, 1);   /*  - changed to 2 from itunes2 to
+  put32lint (file, 0x0c);/*  - changed to 2 from itunes2 to
 			     3. Probably version.  Had to make this
 			     0xC for shuffle to accept it */
   put32lint (file, 2);   /* two children in total */
