@@ -22,18 +22,20 @@
 | 
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: md5.h,v 1.13 2004/01/17 09:37:48 jcsjcs Exp $
+|  $Id: md5.h,v 1.16 2004/03/23 15:54:29 jcsjcs Exp $
 */
 #ifndef _GTKPOD_MD5_H_
 #define _GTKPOD_MD5_H_
 
-#include "song.h"
+#include "track.h"
 #include <glib.h>
 
 
-gchar *md5_hash_on_file_name (gchar *name);
+gchar *md5_hash_on_filename (gchar *name, gboolean silent);
 /* Any calls to the following functions immediately return if md5sums
  * is not on */
+Track *md5_file_exists (gchar *file, gboolean silent);
+Track *md5_md5_exists (gchar *md5);
 Track *md5_track_exists(Track *s);
 Track *md5_track_exists_insert(Track *s);
 void md5_track_removed(Track *s);
