@@ -1,4 +1,4 @@
-/* Time-stamp: <2005-01-20 21:47:42 jcs>
+/* Time-stamp: <2005-03-10 22:54:00 jcs>
 |
 |  Copyright (C) 2002-2003 Jorg Schuler <jcsjcs at users.sourceforge.net>
 |  Part of the gtkpod project.
@@ -135,6 +135,8 @@
 #include <stdlib.h>
 #include <string.h>
 #include "mp4.h"
+#undef PACKAGE
+#undef VERSION
 #include <config.h>  /* PACKAGE seems to be #undef'ed in mp4.h */
 
 Track *mp4_get_file_info (gchar *mp4FileName)
